## Package for easily creating and formatting frequenly used table model
    pip install simple-qtable-model
    Simple package for creating and formatting a stylized QTableModel

# Usage
    from tableModel.tableStyles import StyledTableWidget

    table_model = StyleTableWidget(QTableWidget)